summaryrefslogtreecommitdiffstats
path: root/canvas/source/directx/dx_canvascustomsprite.hxx
diff options
context:
space:
mode:
authorKurt Zenker <kz@openoffice.org>2008-06-24 09:32:26 +0000
committerKurt Zenker <kz@openoffice.org>2008-06-24 09:32:26 +0000
commitdfb6a8b15c2955b2561bc421b4d5cebd3c27841b (patch)
tree5ecf7a200b6103647d8c34a6992c01c450122138 /canvas/source/directx/dx_canvascustomsprite.hxx
parentINTEGRATION: CWS canvas05 (1.2.2); FILE MERGED (diff)
downloadcore-dfb6a8b15c2955b2561bc421b4d5cebd3c27841b.tar.gz
core-dfb6a8b15c2955b2561bc421b4d5cebd3c27841b.zip
INTEGRATION: CWS canvas05 (1.2.2); FILE MERGED
2008/04/21 07:30:33 thb 1.2.2.3: RESYNC: (1.2-1.3); FILE MERGED 2008/02/11 00:11:30 thb 1.2.2.2: #i81092# Cleaned up some more 2008/01/22 00:25:23 thb 1.2.2.1: #i81092# Making gdiplus and dx canvas more independent
Diffstat (limited to 'canvas/source/directx/dx_canvascustomsprite.hxx')
-rwxr-xr-xcanvas/source/directx/dx_canvascustomsprite.hxx12
1 files changed, 7 insertions, 5 deletions
diff --git a/canvas/source/directx/dx_canvascustomsprite.hxx b/canvas/source/directx/dx_canvascustomsprite.hxx
index e9b3614e0818..73a4b88b19f6 100755
--- a/canvas/source/directx/dx_canvascustomsprite.hxx
+++ b/canvas/source/directx/dx_canvascustomsprite.hxx
@@ -7,7 +7,7 @@
* OpenOffice.org - a multi-platform office productivity suite
*
* $RCSfile: dx_canvascustomsprite.hxx,v $
- * $Revision: 1.3 $
+ * $Revision: 1.4 $
*
* This file is part of OpenOffice.org.
*
@@ -48,7 +48,8 @@
#include <canvas/base/canvascustomspritebase.hxx>
#include "dx_sprite.hxx"
-#include "dx_canvashelper.hxx"
+#include "dx_surfacebitmap.hxx"
+#include "dx_bitmapcanvashelper.hxx"
#include "dx_spritehelper.hxx"
#include "dx_spritecanvas.hxx"
@@ -83,7 +84,7 @@ namespace dxcanvas
typedef ::canvas::CanvasCustomSpriteBase< CanvasCustomSpriteSpriteBase_Base,
SpriteHelper,
- CanvasHelper,
+ BitmapCanvasHelper,
::osl::MutexGuard,
::cppu::OWeakObject > CanvasCustomSpriteBaseT;
@@ -130,10 +131,11 @@ namespace dxcanvas
virtual void redraw() const;
private:
/** MUST hold here, too, since CanvasHelper only contains a
raw pointer (without refcounting)
*/
- SpriteCanvasRef mpSpriteCanvas;
+ SpriteCanvasRef mpSpriteCanvas;
+ DXSurfaceBitmapSharedPtr mpSurface;
};
}
@@ -130,10 +131,11 @@ namespace dxcanvas
virtual void redraw() const;
private:
- /** MUST hold here, too, since CanvasHelper only contains a
+ /** MUST hold here, too, since BitmapCanvasHelper only contains a
raw pointer (without refcounting)
*/